@@ -105,7 +105,11 @@ class Form(object):
         self._dbsession = dbsession
         self._request = request
         self._csrf_token = csrf_token
-        self._eval_url = eval_url
+        if request:
+            base_url = request.application_url
+            self._eval_url = base_url + eval_url
+        else:
+            self._eval_url = eval_url
         if translate:
             self._translate = translate
         else:
@@ -757,7 +761,7 @@ class Field(object):
             options = self.get_options()
             for opt in options:
                 for v in value:
-                    if str(v) == str(opt[1]):
+                    if unicode(v) == unicode(opt[1]):
                         ex_values.append("%s" % opt[0])
             return ", ".join(ex_values)
         else:
